@@ -1,6 +1,6 @@
 /* Xsynth DSSI software synthesizer plugin
  *
- * Copyright (C) 2004 Sean Bolton.
+ * Copyright (C) 2004, 2009 Sean Bolton.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
- * MA 02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 /* Ah, the gentle tedium of moving all possible conditionals outside
@@ -36,32 +36,32 @@
  */
 
 #ifdef BLOSC_SINGLE1
-#define BLOSC_THIS(x, ...) blosc_single1##x(__VA_ARGS__)
+/* #define BLOSC_THIS(x, ...) blosc_single1##x(__VA_ARGS__) */
+#define BLOSC_THIS(x, args...) blosc_single1##x(args)
 #define BLOSC_W_TABLE 0
 #endif
 #ifdef BLOSC_MASTER
-#define BLOSC_THIS(x, ...) blosc_master##x(__VA_ARGS__)
+#define BLOSC_THIS(x, args...) blosc_master##x(args)
 #define BLOSC_W_TABLE 0
 #endif
 #ifdef BLOSC_SINGLE2
-#define BLOSC_THIS(x, ...) blosc_single2##x(__VA_ARGS__)
+#define BLOSC_THIS(x, args...) blosc_single2##x(args)
 #define BLOSC_W_TABLE 1
 #endif
 #ifdef BLOSC_SLAVE
-#define BLOSC_THIS(x, ...) blosc_slave##x(__VA_ARGS__)
+#define BLOSC_THIS(x, args...) blosc_slave##x(args)
 #define BLOSC_W_TABLE 1
 #endif
 
 /* ==== blosc_*sine functions ==== */
 
 /* static inline */ void
-BLOSC_THIS(sine, unsigned long sample_count,
-           xsynth_voice_t *voice, struct blosc *osc,
-           int index, float gain,
 #if BLOSC_W_TABLE
-           float *wp)
+BLOSC_THIS(sine, unsigned long sample_count, xsynth_voice_t *voice,
+           struct blosc *osc, int index, float gain, float *wp)
 #else
-           float w)
+BLOSC_THIS(sine, unsigned long sample_count, xsynth_voice_t *voice,
+           struct blosc *osc, int index, float gain, float w)
 #endif
 {
     unsigned long sample;
@@ -135,13 +135,12 @@ BLOSC_THIS(sine, unsigned long sample_count,
 /* ==== blosc_*tri functions ==== */
 
 /* static inline */ void
-BLOSC_THIS(tri, unsigned long sample_count,
-           xsynth_voice_t *voice, struct blosc *osc,
-           int index, float gain,
 #if BLOSC_W_TABLE
-           float *wp)
+BLOSC_THIS(tri, unsigned long sample_count, xsynth_voice_t *voice,
+           struct blosc *osc, int index, float gain, float *wp)
 #else
-           float w)
+BLOSC_THIS(tri, unsigned long sample_count, xsynth_voice_t *voice,
+           struct blosc *osc, int index, float gain, float w)
 #endif
 {
     unsigned long sample;
@@ -292,13 +291,12 @@ BLOSC_THIS(tri, unsigned long sample_count,
 /* ==== blosc_*sawup functions ==== */
 
 /* static inline */ void
-BLOSC_THIS(sawup, unsigned long sample_count,
-           xsynth_voice_t *voice, struct blosc *osc,
-           int index, float gain,
 #if BLOSC_W_TABLE
-           float *wp)
+BLOSC_THIS(sawup, unsigned long sample_count, xsynth_voice_t *voice,
+           struct blosc *osc, int index, float gain, float *wp)
 #else
-           float w)
+BLOSC_THIS(sawup, unsigned long sample_count, xsynth_voice_t *voice,
+           struct blosc *osc, int index, float gain, float w)
 #endif
 {
     unsigned long sample;
@@ -364,13 +362,12 @@ BLOSC_THIS(sawup, unsigned long sample_count,
 /* ==== blosc_*sawdown functions ==== */
 
 /* static inline */ void
-BLOSC_THIS(sawdown, unsigned long sample_count,
-           xsynth_voice_t *voice, struct blosc *osc,
-           int index, float gain,
 #if BLOSC_W_TABLE
-           float *wp)
+BLOSC_THIS(sawdown, unsigned long sample_count, xsynth_voice_t *voice,
+           struct blosc *osc, int index, float gain, float *wp)
 #else
-           float w)
+BLOSC_THIS(sawdown, unsigned long sample_count, xsynth_voice_t *voice,
+           struct blosc *osc, int index, float gain, float w)
 #endif
 {
     unsigned long sample;
@@ -436,13 +433,12 @@ BLOSC_THIS(sawdown, unsigned long sample_count,
 /* ==== blosc_*rect functions ==== */
 
 /* static inline */ void
-BLOSC_THIS(rect, unsigned long sample_count,
-           xsynth_voice_t *voice, struct blosc *osc,
-           int index, float gain,
 #if BLOSC_W_TABLE
-           float *wp)
+BLOSC_THIS(rect, unsigned long sample_count, xsynth_voice_t *voice,
+           struct blosc *osc, int index, float gain, float *wp)
 #else
-           float w)
+BLOSC_THIS(rect, unsigned long sample_count, xsynth_voice_t *voice,
+           struct blosc *osc, int index, float gain, float w)
 #endif
 {
     unsigned long sample;
@@ -590,13 +586,12 @@ BLOSC_THIS(rect, unsigned long sample_count,
 /* ==== blosc_* dispatch function ==== */
 
 static inline void
-BLOSC_THIS(, unsigned long sample_count,
-           xsynth_voice_t *voice, struct blosc *osc,
-           int index, float gain,
 #if BLOSC_W_TABLE
-           float *w)
+BLOSC_THIS(, unsigned long sample_count, xsynth_voice_t *voice,
+           struct blosc *osc, int index, float gain, float *w)
 #else
-           float w)
+BLOSC_THIS(, unsigned long sample_count, xsynth_voice_t *voice,
+           struct blosc *osc, int index, float gain, float w)
 #endif
 {
     switch (osc->waveform) {
